@@ -1,9 +1,9 @@
 package Data::ModeMerge::Mode::ADD;
-our $VERSION = '0.21';
+our $VERSION = '0.23';
 # ABSTRACT: Handler for Data::ModeMerge ADD merge mode
 
 
-use Moose;
+use Any::Moose;
 extends 'Data::ModeMerge::Mode::NORMAL';
 
 sub name { 'ADD' }
@@ -61,7 +61,7 @@ sub merge_HASH_ARRAY {
 }
 
 __PACKAGE__->meta->make_immutable;
-no Moose;
+no Any::Moose;
 1;
 
 __END__
@@ -73,7 +73,7 @@ Data::ModeMerge::Mode::ADD - Handler for Data::ModeMerge ADD merge mode
 
 =head1 VERSION
 
-version 0.21
+version 0.23
 
 =head1 SYNOPSIS
 
@@ -89,7 +89,7 @@ This is the class to handle ADD merge mode.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2009 by Steven Haryanto.
+This software is copyright (c) 2010 by Steven Haryanto.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
